@@ -4,8 +4,8 @@ from sdk.utils.strenum import StrEnum
 class DeviceType(StrEnum):
     QPU = "QPU"
     EMU_FREE = "EMU_FREE"
-    EMU_SV = "EMU_SV"
+    EMU_TN = "EMU_TN"
 
     @property
     def configurable(self) -> bool:
-        return self in (DeviceType.EMU_FREE, DeviceType.EMU_SV)
+        return self in (DeviceType.EMU_FREE, DeviceType.EMU_TN)
